@@ -17,9 +17,9 @@ df1 = load_data_pirates().assign(target='pirate').sample(200, replace=True)
 df2 = load_data_king_arthur().assign(target='arthur').sample(200, replace=True)
 df3 = load_data_chat_logs().assign(target='chat').sample(100, replace=True)
 df = pd.concat([df1, df2
-                   , df3
+                   # , df3
                 ])
-# df['target'] = df['target'].apply(lambda x: 0 if "pirate" in x else 1)  # can do with or without
+df['target'] = df['target'].apply(lambda x: 0 if "pirate" in x else 1)  # can do with or without
 ################################################################################################
 
 
@@ -45,14 +45,14 @@ df = pd.concat([df1, df2
 ###############################################################################################
 
 ################################################################################################
-from sklearn import datasets
-
-digits = datasets.load_digits()
-X = digits.images.reshape((len(digits.images), -1))
-df = pd.DataFrame(X)
-df.rename(columns={col: "feat_" + str(col) for col in df.columns}, inplace=True)
-df['target'] = digits.target
-df['target'] = "c_ " + df['target'].astype(str)
+# from sklearn import datasets
+#
+# digits = datasets.load_digits()
+# X = digits.images.reshape((len(digits.images), -1))
+# df = pd.DataFrame(X)
+# df.rename(columns={col: "feat_" + str(col) for col in df.columns}, inplace=True)
+# df['target'] = digits.target
+# df['target'] = "c_ " + df['target'].astype(str)
 
 
 ################################################################################################
@@ -175,8 +175,8 @@ def load_ex5():
 
 
 madcat_collector = run_madcat(Data(df=df, target_column='target'),
-                              is_feature_stats=True,
-                              is_pre_model=True,
+                              is_feature_stats=False,
+                              is_pre_model=False,
                               model_run=ModelRun(n_models=3),
                               is_post_model=True, is_model_weaknesses=True
                               )
